@@ -93,7 +93,6 @@ class AWSpider:
     exposed_functions = []
     peers = {}
     peer_uuids = []
-    failed_peers = {}
     
     def __init__( self, 
                 aws_access_key_id, 
@@ -778,10 +777,9 @@ class AWSpider:
     def _checkPeersCallback( self, discovered ):
 
         existing_peers = set( self.peers.keys() )
-        failed_peers = set( self.failed_peers.keys() )
         discovered_peers = set( discovered.keys() )
-        new_peers = discovered_peers - ( existing_peers | failed_peers )
-        old_peers = ( existing_peers | failed_peers ) - discovered_peers
+        new_peers = discovered_peers - existing_peers
+        old_peers = existing_peers - discovered_peers
         
         deferreds = []
         
@@ -790,7 +788,8 @@ class AWSpider:
                 self.peers[uuid] = {
                     "uri":"http://127.0.0.1:%s" % self.port,
                     "local_ip":"127.0.0.1",
-                    "port":self.port
+                    "port":self.port,
+                    "active":True
                 }
             else:
                 deferreds.append( self.verifyPeer( uuid, discovered[uuid] ) )
@@ -800,9 +799,6 @@ class AWSpider:
             
             if uuid in self.peers:
                 del self.peers[ uuid ]
-                
-            if uuid in self.failed_peers:
-                del self.failed_peers[ uuid ]
         
         if len( new_peers ) > 0:
             if len(deferreds) > 0:
@@ -816,12 +812,16 @@ class AWSpider:
             pass # No old, no new.
         
     def _checkPeersCallback2( self, data ):
+        
         logger.debug( "Re-organizing peers." )
+        
         for uuid in self.peers:
             if "local_ip" in self.peers[uuid]:
                 self.peers[uuid]["uri"] = "http://%s:%s" % (self.peers[uuid]["local_ip"], self.peers[uuid]["port"] )
+                self.peers[uuid]["active"] = True
             elif "public_ip" in self.peers[uuid]:
                 self.peers[uuid]["uri"] = "http://%s:%s" % (self.peers[uuid]["public_ip"], self.peers[uuid]["port"] )
+                self.peers[uuid]["active"] = True
             else:
                 logger.error("Peer %s has no local or public IP. This should not happen." % uuid )
         
@@ -830,12 +830,11 @@ class AWSpider:
         
 #        print self.peers 
         logger.debug( "Peers updated to: %s" % self.peers )
-        logger.debug( "Failed peers updated to: %s" % self.failed_peers )
         # Go through the peers and reorganize the group.
         pass
         
     def _checkPeersErrback( self, error ):
-        print error
+        logger.error( "Could not query SimpleDB for peers: %s" % str(error) )
 
     def verifyPeer( self, uuid, peer ):
         
@@ -847,7 +846,13 @@ class AWSpider:
             port = int(peer["port"][0])
         else:
             port = self.port
+
+        if uuid not in self.peers:
+            self.peers[ uuid ] = {}
             
+        self.peers[ uuid ]["active"] = False
+        self.peers[ uuid ]["port"] = port
+        
         if "local_ip" in peer:
             local_ip = peer["local_ip"][0]
             local_url = "http://%s:%s/data/server" % (local_ip, port)
@@ -861,34 +866,19 @@ class AWSpider:
             d = self.getPage( public_url, timeout=5, cache=-1  )         
             d.addCallback( self._verifyPeerPublicIPCallback, uuid, public_ip, port )
             deferreds.append( d )
-
+        
         if len(deferreds) > 0:
             d = DeferredList( deferreds, consumeErrors=True )
-            d.addCallback( self._verifyPeerCallback, uuid )
             return d
         else:
             return None
     
-    def _verifyPeerCallback( self, data, uuid ):
-
-        for row in data:
-            if row[0] == True:
-                return None
-        self.failed_peers[ uuid ] = True
-    
     def _verifyPeerLocalIPCallback( self, data, uuid, local_ip, port ):
         logger.debug( "Verified local IP for %s" % uuid )
-        if uuid not in self.peers:
-            self.peers[ uuid ] = {}
         self.peers[ uuid ]["local_ip"] = local_ip
-        self.peers[ uuid ]["port"] = port
-        self.peers[ uuid ]["uri"] = "http://%s:%s" % (local_ip, port )
-    
+        
     def _verifyPeerPublicIPCallback( self, data, uuid, public_ip, port ):
         logger.debug( "Verified public IP for %s" % uuid )
-        if uuid not in self.peers:
-            self.peers[ uuid ] = {}
         self.peers[ uuid ]["public_ip"] = public_ip
-        self.peers[ uuid ]["port"] = port
-        self.peers[ uuid ]["uri"] = "http://%s:%s" % (public_ip, port )
         
+
